.. _installation:

===========
First steps
===========

* The easiest way to try this package is using a web-based notebook:

|colab|

.. |colab| image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/JesseBonanno/pySlope/main?filepath=pySlope%2Fexamples%2Freadme_example.ipynb


* You can also download and install the ``pySlope`` package, which runs on Python 3.

  * If you do not have a Python 3 interpreter on your machine, you can install the last version following the instructions in `this tutorial <https://realpython.com/installing-python/>`_.
  * Once you have Python 3, you can open a terminal and install the package with this one-liner::

      python3 -m pip install --user pyslope

    **NOTE**: You may need to replace ``python3`` above by the path to your Python 3 executable, or simply ``python`` if you are running Windows.

This project is completely open source, and the code can be found in this `GitHub repository
<https://github.com/JesseBonanno/IndeterminateBeam/>`_.

* You can fork the package, which runs on Python 3 to play around with the code in your own coding environment.